Module edr

Structs

Edr
EdrBuilder
Use builder syntax to set the inputs and finish with build().
EdrClaims
EdrClaimsBuilder
Use builder syntax to set the inputs and finish with build().
EdrEntry
EdrEntryBuilder
Use builder syntax to set the inputs and finish with build().
RefreshTokenId
TokenId